@@ -11,7 +11,7 @@
 #include <QSize>
 #include <QWindow>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct wl_surface;
 struct wl_shell;
